bayespy.inference.vmp.nodes.gaussian.GaussianGammaDistribution
==============================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. autoclass:: GaussianGammaDistribution

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: generated/
   
      ~GaussianGammaDistribution.__init__
      ~GaussianGammaDistribution.compute_cgf_from_parents
      ~GaussianGammaDistribution.compute_fixed_moments_and_f
      ~GaussianGammaDistribution.compute_gradient
      ~GaussianGammaDistribution.compute_logpdf
      ~GaussianGammaDistribution.compute_message_to_parent
      ~GaussianGammaDistribution.compute_moments_and_cgf
      ~GaussianGammaDistribution.compute_phi_from_parents
      ~GaussianGammaDistribution.compute_weights_to_parent
      ~GaussianGammaDistribution.plates_from_parent
      ~GaussianGammaDistribution.plates_to_parent
      ~GaussianGammaDistribution.random
   
   

   
   
   